@@ -20,7 +20,7 @@
 
   ---
 
-  $Id: pipemeter.c 102 2007-07-20 07:12:24Z clint $
+  $Id$
   
 */
 
@@ -397,7 +397,7 @@ void show_just_rate(int sig) {
     fprintf(stderr,"\n");
     exit(1);
   } else {
-    fprintf(stderr,trailer);
+    fputs(trailer,stderr);
   }
 }
  
@@ -487,7 +487,7 @@ void show_progress(int sig) {
   }
 
   strncpy(progressbar+1,progressfill,progress);
-  fprintf(stderr, progressbar);
+  fputs(progressbar,stderr);
   fprintf(stderr," %s/s",buf2);
   formatbytes(buf2,bytes);
   fprintf(stderr," %s",buf2);
@@ -497,7 +497,7 @@ void show_progress(int sig) {
     fprintf(stderr,"\n");
     exit(0);
   } else {
-    fprintf(stderr,trailer);
+    fputs(trailer,stderr);
   }
 }
 
